%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Config file for DynamicReverseEngine
% Rule used syntax ProLog (with tuProlog enhancement)
% Last update for v."Ontos"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%--- set home URL page
home_url_page(URL):- 
  URL = 'http://www.ontospace.net'.

%--- set SQL for find objects --

sql_objects(User,SQL):-
 tc([ ' select owner,object_name,object_type,status ',
      ' from all_objects ',
      ' where owner = ''',User,''' and ',
         ' object_type like ''TABLE%'''
     ],'',SQL).

%--- set background picture ---

picture(X):-
  X = 'images/2p.jpeg'.

%---- set send mail param

sendmail(
  host('mail.smtp.host'),     % virtual host
  server('mail.speakeasy.net'),
  to('ngs@ontospace.net'),
  from('***@***.***'),
  subj('Recommend'),
  body('Hello')
).

%-- set skin window ---

lookandfeel(X):-
  X = 'javax.swing.plaf.metal.MetalLookAndFeel'.
  % X = 'com.sun.java.swing.plaf.windows.WindowsLookAndFeel'.

%--- set panel color ----

panelcolor(
  back('#522c21'),
  fore('#5dc1b1')
).

%--- set panel line color ------

linecolor(
  arrow('#fefe00'),
  line('#005da3'),
  focus('#00dbee'),
  setfocus('#fe6100')
).

%--- set panel object box color ---

boxcolor(
  outline('#00ec00'),
  label('#000000')
).

%-- set font for label box diagram -----

font( name('Dialog'),type('0'),size('12') ).

%-- set font for tree objects search -----

tfontos( name('MSSerif'),type('0'),size('9') ).

%--- set type objects Oracle ------

object_type(1,   'TABLE',
   color( back('#ffffff'), fore('#005da3') )
).
object_type(2,'MATERIALIZED VIEW',
  color( back('#b8d156'), fore('#d1156e') )
).
object_type(3,   'VIEW',
  color( back('#005da3'), fore('#00ec00') )
).
object_type(4,   'TRIGGER',
  color( back('#ff0000'), fore('#00ec00') )
).
object_type(5,   'PROCEDURE',
  color( back('fe6100'), fore('#000513') )
).
object_type(6,   'FUNCTION',
  color( back('#93d8a0'), fore('#000513') )
).
object_type(7,   'PACKAGE',
  color( back('#00bb00'), fore('#00005b') )
).
object_type(8,   'PACKAGE BODY',
  color( back('#00bb00'), fore('#00005b') )
).
object_type(9,   'INDEX',
  color( back('#931b93'), fore('#00f42a') )
).
object_type(10,  'JAVA CLASS',
  color( back('#7e0000'), fore('#00d900') )
).
object_type(11, 'JAVA DATA',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(12, 'JAVA RESOURCE',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(13, 'JAVA SOURCE',
  color( back('#7e0000'), fore('#00d900') )
).
object_type(14, 'LIBRARY',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(15, 'LOB',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(16, 'OPERATOR',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(17, 'QUEUE',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(18,'SEQUENCE',
  color( back('#e680a0'), fore('#00f42a') )
).
object_type(19,   'SYNONYM',
  color( back('#8906a0'), fore('#00d12a') )
).
object_type(20,   'TYPE',
  color( back('#2d06a0'), fore('#00fe2a') )
).
object_type(21,   'TYPE BODY',
  color( back('#2d0689'), fore('#00ad2a') )
).
object_type(22,   'TYPE_OBJECT',
  color( back('#e60000'), fore('#00f000') )
).
object_type(23,   'TYPE_COLLECTION',
  color( back('#a90060'), fore('#c0c3c1') )
).
object_type(24,'MATERIALIZED VIEW LOG',
  color( back('#c368b1'), fore('#e3c896') )
).
object_type(25,'TABLE PARTITION',
   color( back('#008e00'), fore('#000000') )
).
object_type(26,'TABLE COLUMN',
   color( back('#2f82ee'), fore('#00ec00') )
).
object_type(_,   'NULL',
  color( back('#000000'), fore('#000000') )
).

%%%% New section with version "Jinn"

%--- Get information SQL about current object diagram ---

infObj(ObjName,SQL):-
  % text_concat('select * from all_objects where object_name = ',ObjName,SQL).
  text_concat(
       'select B.column_name,\
               decode(B.column_name,\
               ''OWNER'',A.OWNER,\
               ''OBJECT_NAME'',A.OBJECT_NAME,\
               ''SUBOBJECT_NAME'',A.SUBOBJECT_NAME,\
               ''OBJECT_ID'',A.OBJECT_ID,\
               ''DATA_OBJECT_ID'',A.DATA_OBJECT_ID,\
               ''OBJECT_TYPE'',A.OBJECT_TYPE,\
               ''CREATED'',A.CREATED,\
               ''LAST_DDL_TIME'',A.LAST_DDL_TIME,\
               ''TIMESTAMP'',A.TIMESTAMP,\
               ''STATUS'',A.STATUS,\
               ''TEMPORARY'',A.TEMPORARY,\
               ''GENERATED'',A.GENERATED,\
               ''SECONDARY'',A.SECONDARY,\
	        null) INFO, \
       B.comments from all_objects A, all_col_comments B \
       where B.table_name = ''ALL_OBJECTS'' and \
       A.object_name = ',ObjName,SQL).

%--- Get source text SQL about current object diagram this type ---

srcObj('PROCEDURE',ObjName,SQL):-
  tc([ 'select text from user_source where name = ',ObjName,
       ' and type = ''PROCEDURE'' order by line'],'',SQL).

srcObj('FUNCTION',ObjName,SQL):-
  tc(['select text from user_source where name = ',ObjName,
      ' and type = ''FUNCTION'' order by line'],'',SQL).

srcObj('PACKAGE',ObjName,SQL):-
  tc(['select text from user_source where name = ',ObjName,
      ' and type = ''PACKAGE'' order by line'],'',SQL).

srcObj('PACKAGE BODY',ObjName,SQL):-
  tc(['select text from user_source where name = ',ObjName,
     ' and type = ''PACKAGE BODY'' order by line'],'',SQL).

srcObj('INDEX',ObjName,SQL):-
  text_concat('select * from user_indexes where index_name = ',ObjName,SQL).

srcObj('VIEW',ObjName,SQL):-
  text_concat('select ''view ''||view_name||'' as '',text \
               from user_views \
               where view_name = ',ObjName,SQL).

srcObj('TRIGGER',ObjName,SQL):-
  text_concat('select ''trigger ''||description,trigger_body \
               from user_triggers \
               where trigger_name = ',ObjName,SQL).

srcObj('SEQUENCE',ObjName,SQL):-
  text_concat('select * from user_sequences where sequence_name = ',ObjName,SQL).

srcObj(_,_,'select ''Err SQL..'' from dual').

%

showCom('TABLE',ObjName,SQL):- 
  showCom1(ObjName,SQL).

showCom('VIEW',ObjName,SQL):- 
  showCom1(ObjName,SQL).

showCom('MATERIALIZED VIEW',ObjName,SQL):-
  showCom1(ObjName,SQL).

showCom('SYNONYM',ObjName,SQL):- 
  showCom1(ObjName,SQL).

showCom(_,_,'select ''No comment define for object..'' from dual').

showCom1(ObjName,SQL):-
  text_concat('select B.column_name, \
               decode(B.column_name, \
               ''TABLE_NAME'',A.TABLE_NAME, \
               ''TABLE_TYPE'',A.TABLE_TYPE, \
               ''COMMENTS'',A.COMMENTS, \
	        null) INFO, \
            B.comments \
	   from user_tab_comments A, all_col_comments B  \
       where B.table_name = ''USER_TAB_COMMENTS'' and \
             A.table_name = ',ObjName,SQL).

%

shortShowComCol(TableOwner,TableName,ColumnName,SQL):-
  tc(['select comments from all_col_comments \
       where owner = ',TableOwner,
        ' and table_name = ',TableName,
        ' and column_name = ',ColumnName ],'',SQL).

shortShowComCol(_,_,'select ''_'' from dual').

%

shortShowCom('COLUMN',ObjName,SQL):- 
  text_concat('select comments from user_tab_comments where table_name = ',ObjName,SQL).

shortShowCom('TABLE',ObjName,SQL):- 
  text_concat('select comments from user_tab_comments where table_name = ',ObjName,SQL).

shortShowCom('SYNONYM',ObjName,SQL):- 
  text_concat('select comments from user_tab_comments where table_name = ',ObjName,SQL).

shortShowCom('VIEW',ObjName,SQL):- 
  text_concat('select comments from user_tab_comments where table_name = ',ObjName,SQL).

shortShowCom('MATERIALIZED VIEW',ObjName,SQL):- 
  text_concat('select comments from user_tab_comments where table_name = ',ObjName,SQL).

shortShowCom(_,_,'select ''_'' from dual').

%

colTabCom(TableOwner,TableName,ColumnName,SQL):-
  tc(['select * from all_col_comments \
       where owner = ',TableOwner,
        ' and table_name = ',TableName,
        ' and column_name = ',ColumnName ],'',SQL).

infoTabCom(TableOwner,TableName,ColumnName,SQL):-
   tc([ 'select * from all_tab_columns where owner = ',TableOwner,
        ' and table_name = ',TableName,' and column_name = ',ColumnName ],'',SQL).

%

colTabGrid('COLLECTION',TableOwner,TableName,ColumnName,SQL):-
  tc(['select L.*,T.rowid from "',
         TableOwner,'"."',TableName,'" T,table(T.',ColumnName,') L'
     ],'',SQL).

colTabGrid('CLOB',TableOwner,TableName,ColumnName,SQL):-
  tc(['select replace(DBMS_LOB.SUBSTR(T.',
           ColumnName,',100,1),chr(10),'' '') ',
           ColumnName,',rowid ',
      ' from "',TableOwner,'"."',TableName,'" T '
     ],'',SQL).

colTabGrid('XMLTYPE',TableOwner,TableName,ColumnName,SQL):-
  tc(['select replace(DBMS_LOB.SUBSTR(T.',
           ColumnName,'.getClobVal(),100,1),chr(10),'' '') ',
           ColumnName,',rowid ',
      ' from "',TableOwner,'"."',TableName,'" T '
     ],'',SQL).

colTabGrid('BLOB',TableOwner,TableName,ColumnName,SQL):-
  tc(['select decode(DBMS_LOB.SUBSTR(T.',
       ColumnName,',1,1),null,''NULL'',''(ORABLOB)'') ',
       ColumnName,',rowid ',
      ' from "',TableOwner,'"."',TableName,'" T '
     ],'',SQL).

colTabGrid('COMMON',TableOwner,TableName,ColumnName,SQL):-
  tc(['select T.',ColumnName,',rowid ',
      ' from "',TableOwner,'"."',TableName,'" T '
     ],'',SQL).

%

srcObjg('TABLE',ObjOwner,ObjName,SQL):-
  tc(['select t.*,rowid from "',ObjOwner,'"."',ObjName,'" t'],'',SQL).

srcObjg('TABLE PARTITION',ObjOwner,ObjName,SQL):-
  tc(['select t.*,rowid from "',ObjOwner,'"."',ObjName,'" t'],'',SQL).

srcObjg('MATERIALIZED VIEW',ObjOwner,ObjName,SQL):-
  tc(['select t.*,rowid from "',ObjOwner,'"."',ObjName,'" t'],'',SQL).

srcObjg('VIEW',ObjOwner,ObjName,SQL):-
  tc(['select t.* from "',ObjOwner,'"."',ObjName,'" t'],'',SQL).

srcObjg('SYNONYM',ObjOwner,ObjName,SQL):-
  tc(['select t.*,rowid from "',ObjOwner,'"."',ObjName,'" t'],'',SQL).

%

srcObjTP('TABLE PARTITION',ObjOwner,ObjName,ObjNamePart,SQL):-
  tc(['select * from "',ObjOwner,'"."',ObjName,
              '" partition("',ObjNamePart,'")'],'',SQL).

%----------   my service Prolog rules..  ------------------------------

tc([],S,S).
tc([T|L],S0,S):- 
  text_concat(S0,T,S1), 
  tc(L,S1,S).

